@@ -394,18 +394,26 @@ while 1:
           if DEBUG:
             log("%d of %s has a recently ended job with %d seconds left of grace to check results" % (sessnum, username, row[0]))
 
-    #
-    # calculation using "walltime", which may be wildly inaccurate, 
-    # which is why the "end" column was added with an automatic timestamp
-    # doing this calculation can only help prevent expiring a session too early so it does no harm
-    # walltime here is supposed to be in seconds;  the condition "walltime < UNIX_TIMESTAMP(start)" prevents cases
-    # where the walltime is instead a timestamp.
-    job_arr = mysql(c, """SELECT %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") AS remaining
-      FROM joblog WHERE sessnum = "%s"
-      AND walltime < UNIX_TIMESTAMP(start)
-      AND job > 0
-      AND end = '0000-00-00 00:00:00'
-      AND %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") > 0""" % (timeout, curtime, sessnum, timeout, curtime))
+      #
+      # calculation using "walltime", which may be wildly inaccurate, 
+      # which is why the "end" column was added with an automatic timestamp
+      # doing this calculation can only help prevent expiring a session too early so it does no harm
+      # walltime here is supposed to be in seconds;  the condition "walltime < UNIX_TIMESTAMP(start)" prevents cases
+      # where the walltime is instead a timestamp.
+      job_arr = mysql(c, """SELECT %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") AS remaining
+        FROM joblog WHERE sessnum = "%s"
+        AND walltime < UNIX_TIMESTAMP(start)
+        AND job > 0
+        AND end = '0000-00-00 00:00:00'
+        AND %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") > 0""" % (timeout, curtime, sessnum, timeout, curtime))
+    else:
+      # calculation using "walltime", as above but without referencing "end" column
+      job_arr = mysql(c, """SELECT %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") AS remaining
+        FROM joblog WHERE sessnum = "%s"
+        AND walltime < UNIX_TIMESTAMP(start)
+        AND job > 0
+        AND %d + walltime - TIMESTAMPDIFF(SECOND, start, "%s") > 0""" % (timeout, curtime, sessnum, timeout, curtime))
+     
     if job_arr:
       for row in job_arr:
         remaining = row[0]
